@@ -7,10 +7,9 @@ import click
 from betterboto import client as betterboto_client
 from jinja2 import Template
 
-from servicecatalog_puppet import constants, asset_helpers, config
+from servicecatalog_puppet import constants, asset_helpers
 
-logger = logging.getLogger()
-logger.setLevel(logging.INFO)
+logger = logging.getLogger(constants.PUPPET_LOGGER_NAME)
 
 
 def set_org_iam_role_arn(org_iam_role_arn):
@@ -51,9 +50,6 @@ def bootstrap_org_master(puppet_account_id):
                 },
             ],
             "Tags": [{"Key": "ServiceCatalogPuppet:Actor", "Value": "Framework",}],
-            "ShouldDeleteRollbackComplete": config.get_should_delete_rollback_complete_stacks(
-                puppet_account_id
-            ),
         }
         cloudformation.create_or_update(**args)
         response = cloudformation.describe_stacks(StackName=stack_name)
